==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/artemis-unit-test-support/src/main/java/org/apache/activemq/artemis/utils/SilentTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.utils;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;

/**
 * Test case that hijacks sys-out and sys-err.
 * <p>
 * It is meant to avoid cluttering either during test execution when the tested code (expectedly)
 * writes to these.
 */
public abstract class SilentTestCase extends Assert {

   private PrintStream origSysOut;
   private PrintStream origSysErr;

   private PrintStream sysOut;
   private PrintStream sysErr;

   @Before
   public void setUp() throws Exception {
      origSysOut = System.out;
      origSysErr = System.err;
      sysOut = new PrintStream(new ByteArrayOutputStream());
      System.setOut(sysOut);
      sysErr = new PrintStream(new ByteArrayOutputStream());
      System.setErr(sysErr);
   }

   @After
   public void tearDown() throws Exception {
      System.setOut(origSysOut);
      System.setErr(origSysErr);
   }
}

==> apache-artemis-2.35.0-source-release.tar.gz: apache-artemis-2.35.0/artemis-unit-test-support/src/main/java/org/apache/activemq/artemis/utils/SilentTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.utils;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;

/**
 * Test case that hijacks sys-out and sys-err.
 * <p>
 * It is meant to avoid cluttering either during test execution when the tested code (expectedly)
 * writes to these.
 */
public abstract class SilentTestCase {

   private PrintStream origSysOut;
   private PrintStream origSysErr;

   private PrintStream sysOut;
   private PrintStream sysErr;

   @BeforeEach
   public void setUp() throws Exception {
      origSysOut = System.out;
      origSysErr = System.err;
      sysOut = new PrintStream(new ByteArrayOutputStream());
      System.setOut(sysOut);
      sysErr = new PrintStream(new ByteArrayOutputStream());
      System.setErr(sysErr);
   }

   @AfterEach
   public void tearDown() throws Exception {
      System.setOut(origSysOut);
      System.setErr(origSysErr);
   }
}
